summaryrefslogtreecommitdiff
path: root/src/being.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/being.h')
-rw-r--r--src/being.h5
1 files changed, 2 insertions, 3 deletions
diff --git a/src/being.h b/src/being.h
index f380e0b8..9ac014e0 100644
--- a/src/being.h
+++ b/src/being.h
@@ -172,9 +172,9 @@ class Being : public ActorSprite, public EventListener
*
* @param victim the victim being
* @param damage the amount of damage dealt (0 means miss)
* @param type the attack type
*/
- virtual void handleAttack(Being *victim, int damage, AttackType type);
+ virtual void handleAttack(Being *victim, int damage, int attackId = 1);
const ItemInfo *getEquippedWeapon() const
{ return mEquippedWeapon; }
@@ -471,7 +471,6 @@ class Being : public ActorSprite, public EventListener
/** Time until the last speech sentence disappears */
int mSpeechTime;
- int mAttackType;
int mAttackSpeed; /**< Attack speed */
Action mAction; /**< Action the being is performing */
@@ -172,9 +172,9 @@ class Being : public ActorSprite, public EventListener
* @param victim the victim being
* @param damage the amount of damage dealt (0 means miss)
- * @param type the attack type
+ * @param attackId the attack id
*/